==> jc-1.4.0.tar.gz: java/security/DummyKeyPairGenerator.h <==
// final class java.security.DummyKeyPairGenerator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 724db494f51ba3f5 java_security_DummyKeyPairGenerator
// @dep_class a5c9129f3f64f19c java_security_KeyPairGenerator
// @dep_class 688f793da35179d1 java_security_KeyPairGeneratorSpi

// header file dependencies
// @dep_header java_security_KeyPairGenerator

#include "java/security/KeyPairGenerator.h"

#ifndef _JC_java_security_DummyKeyPairGenerator_H_
#define _JC_java_security_DummyKeyPairGenerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_KeyPairGeneratorSpi$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_java_security_DummyKeyPairGenerator$sub_refs	_jc_java_security_DummyKeyPairGenerator$sub_refs;
typedef struct _jc_java_security_DummyKeyPairGenerator$sub_nonrefs	_jc_java_security_DummyKeyPairGenerator$sub_nonrefs;
typedef struct _jc_java_security_DummyKeyPairGenerator$refs	_jc_java_security_DummyKeyPairGenerator$refs;
typedef struct _jc_java_security_DummyKeyPairGenerator$nonrefs	_jc_java_security_DummyKeyPairGenerator$nonrefs;
typedef struct _jc_java_security_DummyKeyPairGenerator$object	_jc_java_security_DummyKeyPairGenerator$object;

typedef const struct _jc_java_security_DummyKeyPairGenerator$vmethods	_jc_java_security_DummyKeyPairGenerator$vmethods;
typedef const struct _jc_java_security_DummyKeyPairGenerator$vtable	_jc_java_security_DummyKeyPairGenerator$vtable;
typedef const struct _jc_java_security_DummyKeyPairGenerator$vtype	_jc_java_security_DummyKeyPairGenerator$vtype;

// Constructors
extern void _jc_java_security_DummyKeyPairGenerator$method$_init$8d5ce445670b6820(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, struct _jc_java_security_KeyPairGeneratorSpi$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_DummyKeyPairGenerator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *);
extern struct _jc_java_security_KeyPair$object *_jc_java_security_DummyKeyPairGenerator$method$generateKeyPair$e0a9411286c772d9(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *);
extern void _jc_java_security_DummyKeyPairGenerator$method$initialize$8377579c986315b7(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *);
extern void _jc_java_security_DummyKeyPairGenerator$method$initialize$a73c0ba67824ad04(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
extern void _jc_java_security_DummyKeyPairGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$generateKeyPair$e0a9411286c772d9;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$initialize$8377579c986315b7;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$initialize$a73c0ba67824ad04;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_DummyKeyPairGenerator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *);
	struct _jc_java_security_KeyPair$object	*(*generateKeyPair$e0a9411286c772d9)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *);
	void	(*initialize$8377579c986315b7)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *);
	void	(*initialize$a73c0ba67824ad04)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *);
};

// Vtable
struct _jc_java_security_DummyKeyPairGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPairGeneratorSpi$vmethods	java_security_KeyPairGeneratorSpi;
	_jc_java_security_KeyPairGenerator$vmethods	java_security_KeyPairGenerator;
	_jc_java_security_DummyKeyPairGenerator$vmethods	java_security_DummyKeyPairGenerator;
};

// Vtype
struct _jc_java_security_DummyKeyPairGenerator$vtype {
	_jc_type			type;
	_jc_java_security_DummyKeyPairGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DummyKeyPairGenerator$sub_refs {
	struct _jc_java_security_KeyPairGeneratorSpi$object	*kpgSpi;
};

// Reference instance fields (object)
struct _jc_java_security_DummyKeyPairGenerator$refs {
    _jc_java_security_DummyKeyPairGenerator$sub_refs	java_security_DummyKeyPairGenerator;
    _jc_java_security_KeyPairGenerator$sub_refs	java_security_KeyPairGenerator;
    _jc_java_security_KeyPairGeneratorSpi$sub_refs	java_security_KeyPairGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DummyKeyPairGenerator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_DummyKeyPairGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	java_security_KeyPairGeneratorSpi;
    _jc_java_security_KeyPairGenerator$sub_nonrefs	java_security_KeyPairGenerator;
    _jc_java_security_DummyKeyPairGenerator$sub_nonrefs	java_security_DummyKeyPairGenerator;
};

// Object instance structure
struct _jc_java_security_DummyKeyPairGenerator$object {
	_jc_java_security_DummyKeyPairGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DummyKeyPairGenerator$vtype	*vtype;
	_jc_java_security_DummyKeyPairGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DummyKeyPairGenerator$vtype _jc_java_security_DummyKeyPairGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DummyKeyPairGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DummyKeyPairGenerator$class_object;

#endif	/* _JC_java_security_DummyKeyPairGenerator_H_ */

==> jc-1.4.6.tar.gz: java/security/DummyKeyPairGenerator.h <==
// final class java.security.DummyKeyPairGenerator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 724db494f51ba3f5 java_security_DummyKeyPairGenerator
// @dep_class a5c9129f3f64f19c java_security_KeyPairGenerator
// @dep_class 688f793da35179d1 java_security_KeyPairGeneratorSpi

// header file dependencies
// @dep_header java_security_KeyPairGenerator

#include "java/security/KeyPairGenerator.h"

#ifndef _JC_java_security_DummyKeyPairGenerator_H_
#define _JC_java_security_DummyKeyPairGenerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_KeyPair$object;
struct _jc_java_security_KeyPairGeneratorSpi$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_java_security_DummyKeyPairGenerator$sub_refs	_jc_java_security_DummyKeyPairGenerator$sub_refs;
typedef struct _jc_java_security_DummyKeyPairGenerator$sub_nonrefs	_jc_java_security_DummyKeyPairGenerator$sub_nonrefs;
typedef struct _jc_java_security_DummyKeyPairGenerator$refs	_jc_java_security_DummyKeyPairGenerator$refs;
typedef struct _jc_java_security_DummyKeyPairGenerator$nonrefs	_jc_java_security_DummyKeyPairGenerator$nonrefs;
typedef struct _jc_java_security_DummyKeyPairGenerator$object	_jc_java_security_DummyKeyPairGenerator$object;

typedef const struct _jc_java_security_DummyKeyPairGenerator$vmethods	_jc_java_security_DummyKeyPairGenerator$vmethods;
typedef const struct _jc_java_security_DummyKeyPairGenerator$vtable	_jc_java_security_DummyKeyPairGenerator$vtable;
typedef const struct _jc_java_security_DummyKeyPairGenerator$vtype	_jc_java_security_DummyKeyPairGenerator$vtype;

// Constructors
extern void _jc_java_security_DummyKeyPairGenerator$method$_init$8d5ce445670b6820(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, struct _jc_java_security_KeyPairGeneratorSpi$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_DummyKeyPairGenerator$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_KeyPair$object *_jc_java_security_DummyKeyPairGenerator$method$generateKeyPair$e0a9411286c772d9(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyKeyPairGenerator$method$initialize$8377579c986315b7(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyKeyPairGenerator$method$initialize$a73c0ba67824ad04(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_DummyKeyPairGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$generateKeyPair$e0a9411286c772d9;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$initialize$8377579c986315b7;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$initialize$a73c0ba67824ad04;
extern _jc_method _jc_java_security_DummyKeyPairGenerator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_DummyKeyPairGenerator$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_KeyPair$object	*(*generateKeyPair$e0a9411286c772d9)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *) _JC_JCNI_ATTR;
	void	(*initialize$8377579c986315b7)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*initialize$a73c0ba67824ad04)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_DummyKeyPairGenerator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_DummyKeyPairGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPairGeneratorSpi$vmethods	java_security_KeyPairGeneratorSpi;
	_jc_java_security_KeyPairGenerator$vmethods	java_security_KeyPairGenerator;
	_jc_java_security_DummyKeyPairGenerator$vmethods	java_security_DummyKeyPairGenerator;
};

// Vtype
struct _jc_java_security_DummyKeyPairGenerator$vtype {
	_jc_type			type;
	_jc_java_security_DummyKeyPairGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_DummyKeyPairGenerator$sub_refs {
	struct _jc_java_security_KeyPairGeneratorSpi$object	*kpgSpi;
};

// Reference instance fields (object)
struct _jc_java_security_DummyKeyPairGenerator$refs {
    _jc_java_security_DummyKeyPairGenerator$sub_refs	java_security_DummyKeyPairGenerator;
    _jc_java_security_KeyPairGenerator$sub_refs	java_security_KeyPairGenerator;
    _jc_java_security_KeyPairGeneratorSpi$sub_refs	java_security_KeyPairGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_DummyKeyPairGenerator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_DummyKeyPairGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPairGeneratorSpi$sub_nonrefs	java_security_KeyPairGeneratorSpi;
    _jc_java_security_KeyPairGenerator$sub_nonrefs	java_security_KeyPairGenerator;
    _jc_java_security_DummyKeyPairGenerator$sub_nonrefs	java_security_DummyKeyPairGenerator;
};

// Object instance structure
struct _jc_java_security_DummyKeyPairGenerator$object {
	_jc_java_security_DummyKeyPairGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_DummyKeyPairGenerator$vtype	*vtype;
	_jc_java_security_DummyKeyPairGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_DummyKeyPairGenerator$vtype _jc_java_security_DummyKeyPairGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_DummyKeyPairGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_DummyKeyPairGenerator$class_object;

#endif	/* _JC_java_security_DummyKeyPairGenerator_H_ */
